@@ -164,7 +164,12 @@ select_mirror () {
     case $(hostname --fqdn) in
 	bld-*.mmjgroup.com)	MIRROR=${USERMIRROR};;
 	*.mmjgroup.com)		MIRROR=http://archive.mmjgroup.com/${USERMIRROR##*/};;
-	*.0c3.net)		MIRROR=http://ftp.iinet.net.au/linux/ubuntu;;
+	*.0c3.net)
+		case $ARCH in
+			i386|amd64)	MIRROR=http://mirrors.0c3.net/ubuntu/ ;;
+			*)		MIRROR=http://mirrors.0c3.net/ubuntu-ports/ ;;
+		esac
+		;;
 	*.ubuntu.com)		MIRROR=http://ftpmaster.internal/ubuntu;;
 	*.warthogs.hbd.com)	MIRROR=http://ftpmaster.internal/ubuntu;;
 	*.buildd)		MIRROR=http://ftpmaster.internal/ubuntu;;
@@ -206,9 +211,9 @@ esac; done;
 shift $((OPTIND-1))
 
 if (( $# == 0 )) || [ "X$1" = "Xall" ]; then
-    set -- ubuntu kubuntu kubuntu-mobile kubuntu-netbook edubuntu xubuntu mythbuntu gobuntu base ubuntu-headless
+    set -- ubuntu kubuntu kubuntu-active edubuntu xubuntu mythbuntu gobuntu base ubuntu-headless cloud-live
     if [ "$ARCH" = "i386" ]; then
-        set -- ubuntu ubuntu-dvd kubuntu kubuntu-dvd kubuntu-mobile kubuntu-netbook edubuntu edubuntu-dvd mythbuntu xubuntu gobuntu base ubuntu-headless
+        set -- ubuntu ubuntu-dvd kubuntu kubuntu-dvd kubuntu-active edubuntu edubuntu-dvd mythbuntu xubuntu gobuntu base ubuntu-headless
     fi
 fi
 
@@ -220,7 +225,7 @@ fi
 
 for arg in "$@"; do
     case "$arg" in
-       ubuntu|ubuntu-dvd|ubuntu-lpia|edubuntu|edubuntu-dvd|kubuntu|kubuntu-dvd|kubuntu-mobile|kubuntu-netbook|xubuntu|mythbuntu|gobuntu|ubuntu-mid|ubuntu-netbook|ubuntu-moblin-remix|base|ubuntu-headless|tocd)
+       ubuntu|ubuntu-dvd|ubuntu-lpia|edubuntu|edubuntu-dvd|kubuntu|kubuntu-dvd|kubuntu-active|xubuntu|mythbuntu|gobuntu|ubuntu-mid|ubuntu-netbook|ubuntu-moblin-remix|base|ubuntu-headless|tocd|cloud-live)
 	    ;;
 	*)
 	    echo bad name >&2;
@@ -273,15 +278,11 @@ Flags: seen
 	    LIST="$LIST minimal^ standard^ kubuntu-desktop^"
 	    LIVELIST="kubuntu-live^ laptop-detect $LIVE_BOOT_SCRIPTS"
 	    ;;
-	kubuntu-mobile)
-	    LIST="$LIST minimal^ standard^ kubuntu-mobile^"
-	    LIVELIST="language-support-en kubuntu-mobile-live^ laptop-detect $LIVE_BOOT_SCRIPTS"
+	kubuntu-active)
+	    LIST="$LIST minimal^ standard^ kubuntu-active^"
+	    LIVELIST="kubuntu-active-live^ laptop-detect $LIVE_BOOT_SCRIPTS"
 	    COMP="main restricted universe"
 	    ;;
-	kubuntu-netbook)
-	    LIST="$LIST minimal^ standard^ kubuntu-netbook^"
-	    LIVELIST="language-support-en kubuntu-netbook-live^ laptop-detect $LIVE_BOOT_SCRIPTS"
-	    ;;
 	edubuntu|edubuntu-dvd)
 	    LIST="$LIST minimal^ standard^ edubuntu-desktop-gnome^"
 	    LIVELIST="edubuntu-live^ laptop-detect $LIVE_BOOT_SCRIPTS"
@@ -325,6 +326,12 @@ Flags: seen
 	    LIST="$LIST minimal^ standard^"
 	    LIVELIST="$LIVE_BOOT_SCRIPTS"
 	    ;;
+	cloud-live)
+	    LIST="$LIST minimal^ standard^"
+	    LIVELIST="minimal^ standard^ cloud-live-config $LIVE_BOOT_SCRIPTS"
+	    COMP="main restricted universe"
+	    PPA="cloud-live/config"
+	    ;;
 	tocd)
 	    LIST="$LIST minimal^ standard^"
 	    tocdtmp=`mktemp -d` || exit 1
@@ -523,6 +530,11 @@ Pin-Priority: 900
 	rm -f ${ROOT}var/cache/apt/{,src}pkgcache.bin
     fi
 
+    if [ "$FS" = "cloud-live" ]; then
+	chroot $ROOT apt-key adv --keyserver keyserver.ubuntu.com --recv-keys F3531FCE
+	chroot $ROOT apt-get update
+    fi
+
     # In addition to the ones we got from apt, trust whatever the local system
     # believes in, but put things back afterwards.
     cp ${ROOT}etc/apt/trusted.gpg ${ROOT}etc/apt/trusted.gpg.$$
@@ -723,8 +735,7 @@ Pin-Priority: 550
 
     # No point keeping Gnome icon cache around for Kubuntu
     if [ "$FS" = "kubuntu" ] || \
-       [ "$FS" = "kubuntu-netbook" ] || \
-       [ "$FS" = "kubuntu-mobile" ]; then
+       [ "$FS" = "kubuntu-active" ]; then
         rm -f ${ROOT}/usr/share/icons/*/icon-theme.cache
     fi
 
